pub struct AudioCodecId(/* private fields */);Expand description
An AudioCodecId is a unique identifier used to identify a specific audio codec.
Creating a Codec ID
Using a well-known codec ID is highly recommended to maximize compatibility
between components, libraries, and applications. However, if a codec requires custom codec ID,
or there is no well-known ID, then the FourCc for the codec may be converted into a codec
ID.
Implementations
Sourceimpl AudioCodecId
impl AudioCodecId
Sourcepub const fn new(cc: FourCc) -> AudioCodecId
pub const fn new(cc: FourCc) -> AudioCodecId
Create a new audio codec ID from a FourCC.