#[non_exhaustive]pub struct AudioDecoderOptions {
pub gapless: bool,
pub verify: bool,
}Expand description
AudioDecoderOptions is a common set of options that all audio decoders use.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.gapless: boolEnable support for gapless playback.
When enabled, the decoder will trim any delay or padding frames.
Default: true.
verify: boolThe decoded audio should be verified if possible during the decode process.
Default: false.
Implementations