pub struct CodecProfile(/* private fields */);Expand description
A codec-specific identification code for a profile.
In general, codec profiles are designed to target specific applications, and define a set of minimum capabilities a decoder must implement to successfully decode a bitstream. For an encoder, a profile imposes a set of constraints upon the bitstream it produces.
Implementations