pub struct VideoCodecId(/* private fields */);Expand description
An VideoCodecId is a unique identifier used to identify a specific video codec.
Creating a Codec ID
Using a well-known codec ID is highly recommended to maximize compatibility
between components, libraries, and applications. However, if a codec requires custom codec ID,
or there is no well-known ID, then the FourCc for the codec may be converted into a codec
ID.
Implementations
Sourceimpl VideoCodecId
impl VideoCodecId
Sourcepub const fn new(cc: FourCc) -> VideoCodecId
pub const fn new(cc: FourCc) -> VideoCodecId
Create a new video codec ID from a FourCC.